==> dwarfg_install_1.3.0.tgz: dwarfg_install/appdir/web/gui/src/Entity/Alert/AlertTargetSpec.php <==
<?php

declare(strict_types=1);

namespace App\Entity\Alert;

use App\Entity\Types\TypesValueType;
use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;
use Doctrine\DBAL\Types\Types;
use Doctrine\ORM\Mapping as ORM;

#[ORM\Table(name: 'alert_target_spec')]
#[ORM\Entity]
class AlertTargetSpec implements \Stringable
{
    /**
     * @var int|null
     */
    #[ORM\Column(type: Types::INTEGER)]
    #[ORM\Id]
    #[ORM\GeneratedValue(strategy: 'AUTO')]
    private ?int $id = null;

    /**
     * @var string
     */
    #[ORM\Column(type: Types::STRING, length: 64, unique: true, nullable: false)]
    public string $name;

    /**
     * @var TypesValueType
     */
    #[ORM\ManyToOne(targetEntity: TypesValueType::class, inversedBy: 'alertTargetSpecs')]
    #[ORM\JoinColumn(name: 'valtype')]
    public TypesValueType $valType;

    /**
     * @var AlertTableSelection
     */
    #[ORM\ManyToOne(targetEntity: AlertTableSelection::class, inversedBy: 'alertTargetSpec')]
    #[ORM\JoinColumn(name: 'seltype')]
    public AlertTableSelection $selType;

    /**
     * @var Collection
     */
    #[ORM\OneToMany(mappedBy: 'targetSpec', targetEntity: AlertTargetMap::class, cascade: ['persist'])]
    #[ORM\JoinColumn(name: 'id')]
    public Collection $targetMaps;

    /**
     * @var Collection
     */
    #[ORM\OneToMany(mappedBy: 'targetSpec', targetEntity: Alert::class, cascade: ['persist'])]
    #[ORM\JoinColumn(name: 'target_spec')]
    public Collection $alerts;

    /**
     * @var string
     */
    #[ORM\Column(type: Types::STRING, length: 64, unique: true, nullable: false)]
    public string $hint;

    /**
     * AlertTargetSpec constructor
     */
    public function __construct() {

        $this->targetMaps = new ArrayCollection();
        $this->alerts = new ArrayCollection();

    }

    /**
     * @return int|null
     */
    public function getId(): ?int {

        return $this->id;

    }

    /**
     * @return string
     */
    public function getName(): string {

        return $this->name;

    }

    /**
     * @return TypesValueType
     */
    public function getValType(): TypesValueType {

        return $this->valType;

    }

    /**
     * @return AlertTableSelection
     */
    public function getSelType(): AlertTableSelection {

        return $this->selType;

    }

    /**
     * @return string
     */
    public function getHint(): string {

        return $this->hint;

    }

    /**
     * @return string
     */
    public function __toString(): string {

        return $this->name;

    }

}

==> dwarfg_install_1.9.0.tgz: dwarfg_install/appdir/web/gui/src/Entity/Alert/AlertTargetSpec.php <==
<?php

declare(strict_types=1);

namespace App\Entity\Alert;

use App\Entity\Types\TypesValueType;
use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;
use Doctrine\DBAL\Types\Types;
use Doctrine\ORM\Mapping as ORM;

#[ORM\Table(name: 'alert_target_spec')]
#[ORM\Entity]
class AlertTargetSpec implements \Stringable
{
    /**
     * @var int|null
     */
    #[ORM\Column(type: Types::INTEGER)]
    #[ORM\Id]
    #[ORM\GeneratedValue(strategy: 'AUTO')]
    private ?int $id = null;

    /**
     * @var string
     */
    #[ORM\Column(type: Types::STRING, length: 64, unique: true, nullable: false)]
    public string $name;

	/**
	 * @var string
	 */
	#[ORM\Column(type: Types::STRING, length: 64, unique: true, nullable: false)]
	public string $hint;

	#[ORM\Column(type: Types::INTEGER, length: 5, nullable: false)]
	public int $displayOrder = 0;

    /**
     * @var TypesValueType
     */
    #[ORM\ManyToOne(targetEntity: TypesValueType::class, inversedBy: 'alertTargetSpecs')]
    #[ORM\JoinColumn(name: 'valtype')]
    public TypesValueType $valType;

    /**
     * @var AlertTableSelection
     */
    #[ORM\ManyToOne(targetEntity: AlertTableSelection::class, inversedBy: 'alertTargetSpec')]
    #[ORM\JoinColumn(name: 'seltype')]
    public AlertTableSelection $selType;

    /**
     * @var Collection
     */
    #[ORM\OneToMany(mappedBy: 'targetSpec', targetEntity: AlertTargetMap::class, cascade: ['persist'])]
    #[ORM\JoinColumn(name: 'id')]
    public Collection $targetMaps;

    /**
     * @var Collection
     */
    #[ORM\OneToMany(mappedBy: 'targetSpec', targetEntity: Alert::class, cascade: ['persist'])]
    #[ORM\JoinColumn(name: 'target_spec')]
    public Collection $alerts;

    /**
     * AlertTargetSpec constructor
     */
    public function __construct() {

        $this->targetMaps = new ArrayCollection();
        $this->alerts = new ArrayCollection();

    }

    /**
     * @return int|null
     */
    public function getId(): ?int {

        return $this->id;

    }

    /**
     * @return string
     */
    public function getName(): string {

        return $this->name;

    }

    /**
     * @return TypesValueType
     */
    public function getValType(): TypesValueType {

        return $this->valType;

    }

    /**
     * @return AlertTableSelection
     */
    public function getSelType(): AlertTableSelection {

        return $this->selType;

    }

    /**
     * @return string
     */
    public function getHint(): string {

        return $this->hint;

    }

	/**
	 * @return int
	 */
	public function getDisplayOrder(): int
	{
		return $this->displayOrder;
	}

    /**
     * @return string
     */
    public function __toString(): string {

        return $this->name;

    }

}
